@@ -5,7 +5,11 @@ class DotDict(dict):
         try:
             dict.__getattribute__(self, 'iteritems')
         except AttributeError:
-            dict.__setattr__(self, 'iteritems', dict.__getattribute__(self, 'items'))
+            dict.__setattr__(
+                self,
+                'iteritems',
+                dict.__getattribute__(self, 'items')
+            )
 
     def __getattr__(self, name):
         if name[:2] == '__':
